Package metadata
=================

.. automodule:: drain_swamp.package_metadata
   :members:
   :undoc-members:
   :platform: Unix
   :synopsis: From pyproject.toml, retrieve package author email and name
